@@ -41,20 +41,48 @@ class QueryEngine(object):
         """
         Args:
             host:
-                Hostname of database machine
+                Hostname of database machine. Defaults to 127.0.0.1 or
+                localhost.
             port:
                 Port for db access. Defaults to mongo's default of 27017.
             database:
-                Actual database to access
+                Actual database to access. Defaults to "vasp".
             user:
-                User for db access
+                User for db access. Defaults to None, which means no
+                authentication.
             password:
-                Password for db access
+                Password for db access. Defaults to None, which means no
+                authentication.
             collection:
-                Collection to query. Defaults to tasks.
-            aliases:
+                Collection to query. Defaults to "tasks".
+            aliases_config:
                 An alias dict to use. Defaults to None, which means the default
-                aliases defined in aliases.json is used.
+                aliases defined in "aliases.json" is used. The aliases config
+                should be of the following format::
+
+                    {
+                        "aliases": {
+                            "e_above_hull": "analysis.e_above_hull",
+                            "energy": "output.final_energy",
+                            ....
+                        },
+                        "defaults": {
+                            "state": "successful"
+                        }
+                    }
+
+                The "aliases" key defines mappings, which makes it easier to
+                query for certain nested quantities. While Mongo does make it
+                easy to map collections, it is sometimes beneficial to
+                organize the doc format in a way that is different from the
+                query format.
+                The "defaults" key specifies criteria that should be applied
+                by default to all queries. For example, a collection may
+                contain data from both successful and unsuccessful runs but
+                for most querying purposes, you may want just successful runs
+                only. Note that defaults do not affect explicitly specified
+                criteria, i.e., if you suppy a query for {"state": "killed"},
+                this will override the default for {"state": "successful"}.
         """
         self.host = host
         self.port = port
@@ -74,6 +102,7 @@ class QueryEngine(object):
             self.aliases = aliases_config["aliases"]
             self.defaults = aliases_config["defaults"]
 
+
     def __enter__(self):
         """Allows for use with the 'with' context manager"""
         return self
@@ -92,11 +121,13 @@ class QueryEngine(object):
         Gets all entries in a chemical system, e.g. Li-Fe-O will return all
         Li-O, Fe-O, Li-Fe, Li-Fe-O compounds.
 
-        Caution: Note that the get_entries_in_system and get_entries methods
-        should be used with care. In essence, all entries, GGA, GGA+U or
-        otherwise, are returned.  The dataset is very heterogeneous and not
-        directly comparable.  It is highly recommended that you perform
-        post-processing using pymatgen.entries.compatibility.
+        .. note::
+
+            The get_entries_in_system and get_entries  methods should be used
+            with care. In essence, all entries, GGA, GGA+U or otherwise,
+            are returned.  The dataset is very heterogeneous and not
+            directly comparable.  It is highly recommended that you perform
+            post-processing using pymatgen.entries.compatibility.
 
         Args:
             elements:
@@ -126,11 +157,13 @@ class QueryEngine(object):
         """
         Get ComputedEntries satisfying a particular criteria.
 
-        Caution: Note that the get_entries_in_system and get_entries methods
-        should be used with care. In essence, all entries, GGA, GGA+U or
-        otherwise, are returned.  The dataset is very heterogeneous and not
-        directly comparable.  It is highly recommended that you perform
-        post-processing using pymatgen.entries.compatibility.
+        .. note::
+
+            The get_entries_in_system and get_entries  methods should be used
+            with care. In essence, all entries, GGA, GGA+U or otherwise,
+            are returned.  The dataset is very heterogeneous and not
+            directly comparable.  It is highly recommended that you perform
+            post-processing using pymatgen.entries.compatibility.
 
         Args:
             criteria:
@@ -272,6 +305,13 @@ class QueryEngine(object):
     def get_structure_from_id(self, task_id, final_structure=True):
         """
         Returns a structure from the database given the task id.
+
+        Args:
+            task_id:
+                The task_id to query for.
+            final_structure:
+                Whether to obtain the final or initial structure. Defaults to
+                True.
         """
         args = {'task_id': task_id}
         field = 'output.crystal' if final_structure else 'input.crystal'
